@@ -79,11 +79,11 @@
 #include <iostream>
 #include <iomanip>
 #include <cstdio>
-#include <climits>
 #include <string>
 #include <list>
 #include <map>
 #include <vector>
+#include <limits>
 
 using namespace std;
 
@@ -158,7 +158,7 @@ FILE *targetfh(NULL), *datafh(NULL), *tempfh(NULL);
 
 bool reuse_as_tempfile(false);
 
-int workThreads=2;
+int workThreads=3;
 vector<char *> hostpool;
 
 vector<uint64_t> lengths;
@@ -537,17 +537,16 @@ void *inputFeed(void *ptr) {
             }
             DEBUG("Block rest: " << rest);
 
-            if(posAdd==expected_blocks) { // this block is already one too much, ignore it and bail out
-                DEBUG("s2.2");
-                ret=1;
-                cerr << "WARNING: got more data then expected. Trailing data is ignored, your image may be incomplete." <<endl;
-                newstate=STOPMARK;
-            }
-
             if(rest==blocksize) { // zero read, previous block was the last one
                 DEBUG("s2.3");
                 newstate=STOPMARK;
             }
+            else if(posAdd==expected_blocks) { // got data but this block is already one too much, ignore it and bail out
+                DEBUG("s2.2");
+                ret=1;
+                cerr << "WARNING: got more data than expected. Trailing data is ignored, your image may be incomplete." <<endl;
+                newstate=STOPMARK;
+            }
 
             if(rest>0) // padding with zeroes and making sure that the endmark will be set in the next block
             {
@@ -696,6 +695,11 @@ int main(int argc, char **argv)
     uint64_t datasize=0;
     int c;
 
+#ifdef _SC_NPROCESSORS_ONLN
+    workThreads=sysconf(_SC_NPROCESSORS_ONLN);
+    cerr << workThreads << " processor core(s) detected\n";
+#endif
+
     while (1)
     {
         int option_index = 0;
@@ -790,15 +794,12 @@ int main(int argc, char **argv)
                 break;
 
             case 't':
-                workThreads=getsize(optarg);
-                if(!workThreads) {
-#ifdef _SC_NPROCESSORS_ONLN
-                        workThreads=sysconf(_SC_NPROCESSORS_ONLN);
-                        cerr << workThreads << " processor(s) detected\n";
-#else
-                        workThreads=3;
-                        cerr << "Invalid number of work threads, using 3\n";
-#endif
+                {
+                   int nMaxThreads=getsize(optarg);
+                   if(nMaxThreads)
+                      workThreads=nMaxThreads;
+                   else
+                      cerr << "Bad thread count, using default (" << workThreads << ")"<<endl;
                 }
                 break;
 
@@ -809,7 +810,7 @@ int main(int argc, char **argv)
 
     }
 
-    char *fromfile=NULL, *tofile=NULL;
+    const char *fromfile=NULL, *tofile=NULL;
     int test;
 
     if(optind > argc-2) {
@@ -819,7 +820,7 @@ int main(int argc, char **argv)
     while(optind!=argc) {
         if( 0==hostpool.size() && is_pos_number(argv[optind]) )
         {
-		int val=getsize(argv[optind]);
+           int val=getsize(argv[optind]);
             cerr << "Warning, number as file string found. Assuming old command syntax and\n"
                 "choosing compatible parameters (-m -B " << val <<"). See the usage info (-h)\n"
                 "for better/correct parameters."<<endl;
@@ -884,7 +885,7 @@ int main(int argc, char **argv)
 
     expected_blocks=datasize/blocksize;
     if(datasize%blocksize) expected_blocks++;
-    if(!expected_blocks) expected_blocks=INT_MAX;
+    if(!expected_blocks) expected_blocks=std::numeric_limits<int>::max();
 
     datafh=targetfh; // for now
 
